@@ -7,7 +7,7 @@ import logging
 from collections.abc import Callable, Iterable
 from enum import Enum, auto
 from functools import partial
-from typing import Any, cast
+from typing import TYPE_CHECKING, Any, cast
 
 from aiohttp import ClientSession
 
@@ -39,6 +39,7 @@ from ..exceptions import (
     RpcCallError,
     ShellyError,
 )
+from .blerpc import BleRPC
 from .models import (
     ShellyBLEConfig,
     ShellyBLESetConfig,
@@ -88,27 +89,47 @@ class RpcDevice:
 
     def __init__(
         self,
-        ws_context: WsServer,
-        aiohttp_session: ClientSession,
+        ws_context: WsServer | None,
+        aiohttp_session: ClientSession | None,
         options: ConnectionOptions,
+        rpc: WsRPC | BleRPC | None = None,
     ) -> None:
         """Device init."""
-        self.aiohttp_session: ClientSession = aiohttp_session
+        self.aiohttp_session: ClientSession | None = aiohttp_session
         self.options: ConnectionOptions = options
         self._shelly: dict[str, Any] | None = None
         self._status: dict[str, Any] | None = None
         self._event: dict[str, Any] | None = None
         self._config: dict[str, Any] | None = None
         self._dynamic_components: list[dict[str, Any]] = []
-        self._wsrpc = WsRPC(
-            options.ip_address, self._on_notification, port=options.port
-        )
-        sub_id = options.ip_address
-        if options.device_mac:
-            sub_id = options.device_mac
-        self._unsub_ws: Callable | None = ws_context.subscribe_updates(
-            sub_id, partial(self._wsrpc.handle_frame, RPCSource.SERVER)
-        )
+
+        # Create or use provided RPC client
+        if rpc is not None:
+            self._rpc: WsRPC | BleRPC = rpc
+        elif options.ip_address is not None:
+            # WebSocket transport
+            self._rpc = WsRPC(
+                options.ip_address, self._on_notification, port=options.port
+            )
+        else:
+            # BLE transport (guaranteed non-None by ConnectionOptions)
+            if TYPE_CHECKING:
+                assert options.ble_device is not None
+            self._rpc = BleRPC(options.ble_device)
+
+        # Subscribe to WebSocket updates if using WsRPC
+        self._unsub_ws: Callable | None = None
+        if isinstance(self._rpc, WsRPC) and ws_context is not None:
+            # options.ip_address is guaranteed non-None if we have WsRPC
+            if TYPE_CHECKING:
+                assert options.ip_address is not None
+            sub_id = options.ip_address
+            if options.device_mac:
+                sub_id = options.device_mac
+            self._unsub_ws = ws_context.subscribe_updates(
+                sub_id, partial(self._rpc.handle_frame, RPCSource.SERVER)
+            )
+
         self._update_listener: Callable | None = None
         self._initialize_lock = asyncio.Lock()
         self.initialized: bool = False
@@ -118,18 +139,30 @@ class RpcDevice:
     @classmethod
     async def create(
         cls: type[RpcDevice],
-        aiohttp_session: ClientSession,
-        ws_context: WsServer,
+        aiohttp_session: ClientSession | None,
+        ws_context: WsServer | None,
         ip_or_options: IpOrOptionsType,
     ) -> RpcDevice:
         """Device creation."""
-        options = await process_ip_or_options(ip_or_options)
-        _LOGGER.debug(
-            "host %s:%s: RPC device create, MAC: %s",
-            options.ip_address,
-            options.port,
-            options.device_mac,
-        )
+        if isinstance(ip_or_options, ConnectionOptions):
+            options = ip_or_options
+        else:
+            options = await process_ip_or_options(ip_or_options)
+
+        if options.ip_address is not None:
+            _LOGGER.debug(
+                "host %s:%s: RPC device create (WebSocket), MAC: %s",
+                options.ip_address,
+                options.port,
+                options.device_mac,
+            )
+        else:
+            _LOGGER.debug(
+                "device %s: RPC device create (BLE), MAC: %s",
+                options.ble_device.address if options.ble_device else None,
+                options.device_mac,
+            )
+
         return cls(ws_context, aiohttp_session, options)
 
     def _on_notification(
@@ -179,6 +212,8 @@ class RpcDevice:
     @property
     def ip_address(self) -> str:
         """Device ip address."""
+        if self.options.ip_address is None:
+            raise AttributeError("IP address not available for BLE devices")
         return self.options.ip_address
 
     @property
@@ -186,9 +221,15 @@ class RpcDevice:
         """Device port."""
         return self.options.port
 
+    def _device_info_str(self) -> str:
+        """Return device info string for logging."""
+        if self.options.ble_device:
+            return f"BLE device {self.options.ble_device.address}"
+        return f"host {self.options.ip_address}:{self.options.port}"
+
     async def initialize(self) -> None:
         """Device initialization."""
-        _LOGGER.debug("host %s:%s: RPC device initialize", self.ip_address, self.port)
+        _LOGGER.debug("%s: RPC device initialize", self._device_info_str())
         if self._initialize_lock.locked():
             raise RuntimeError("Already initializing")
 
@@ -209,29 +250,36 @@ class RpcDevice:
 
     async def _connect_websocket(self) -> None:
         """Connect device websocket."""
-        ip = self.options.ip_address
-        port = self.options.port
+        device_info = self._device_info_str()
         try:
-            async with asyncio.timeout(DEVICE_IO_TIMEOUT):
-                await self._wsrpc.connect(self.aiohttp_session)
+            # Use DEVICE_INIT_TIMEOUT for connection (BLE needs longer for scanning)
+            async with asyncio.timeout(DEVICE_INIT_TIMEOUT):
+                if isinstance(self._rpc, WsRPC):
+                    if self.aiohttp_session is None:
+                        raise ValueError(
+                            "aiohttp_session required for WebSocket transport"
+                        )
+                    await self._rpc.connect(self.aiohttp_session)
+                else:
+                    await self._rpc.connect()
             await self._init_calls()
         except InvalidAuthError as err:
             self._last_error = InvalidAuthError(err)
-            _LOGGER.debug("host %s:%s: error: %r", ip, port, self._last_error)
-            await self._wsrpc.disconnect()
+            _LOGGER.debug("%s: error: %r", device_info, self._last_error)
+            await self._rpc.disconnect()
             raise
         except MacAddressMismatchError as err:
             self._last_error = err
-            _LOGGER.debug("host %s:%s: error: %r", ip, port, err)
-            await self._wsrpc.disconnect()
+            _LOGGER.debug("%s: error: %r", device_info, err)
+            await self._rpc.disconnect()
             raise
         except (*CONNECT_ERRORS, RpcCallError) as err:
             self._last_error = DeviceConnectionError(err)
-            _LOGGER.debug("host %s:%s: error: %r", ip, port, self._last_error)
-            await self._wsrpc.disconnect()
+            _LOGGER.debug("%s: error: %r", device_info, self._last_error)
+            await self._rpc.disconnect()
             raise self._last_error from err
         else:
-            _LOGGER.debug("host %s:%s: RPC device init finished", ip, port)
+            _LOGGER.debug("%s: RPC device init finished", device_info)
             self.initialized = True
 
     async def shutdown(self) -> None:
@@ -240,7 +288,7 @@ class RpcDevice:
         This method will unsubscribe the update listener and disconnect the websocket.
 
         """
-        _LOGGER.debug("host %s:%s: RPC device shutdown", self.ip_address, self.port)
+        _LOGGER.debug("%s: RPC device shutdown", self._device_info_str())
         self._update_listener = None
         await self._disconnect_websocket()
 
@@ -258,7 +306,7 @@ class RpcDevice:
                 )
             self._unsub_ws = None
 
-        await self._wsrpc.disconnect()
+        await self._rpc.disconnect()
 
     def subscribe_updates(self, update_listener: Callable) -> None:
         """Subscribe to device status updates."""
@@ -448,6 +496,18 @@ class RpcDevice:
             params["intensity"] = intensity
         await self.call_rpc("Cury.Set", params=params)
 
+    async def cury_set_away_mode(
+        self,
+        id_: int,
+        value: bool,
+    ) -> None:
+        """Set away mode for Cury."""
+        params = {
+            "id": id_,
+            "on": value,
+        }
+        await self.call_rpc("Cury.SetAwayMode", params=params)
+
     async def enum_set(self, id_: int, value: str) -> None:
         """Set the value for the enum component."""
         params = {
@@ -464,6 +524,10 @@ class RpcDevice:
         }
         await self.call_rpc("Number.Set", params=params)
 
+    async def smoke_mute_alarm(self, id_: int) -> None:
+        """Mute smoke alarm."""
+        await self.call_rpc("Smoke.Mute", params={"id": id_})
+
     async def switch_set(self, id_: int, value: bool) -> None:
         """Set the value for the switch component."""
         params = {
@@ -525,8 +589,13 @@ class RpcDevice:
         # require auth, so we must do a separate call here to get
         # the auth_domain/id so we can enable auth for the rest of the calls
         self._shelly = await self.call_rpc("Shelly.GetDeviceInfo")
-        if self.options.username and self.options.password:
-            self._wsrpc.set_auth_data(
+        # Auth only supported on WebSocket transport
+        if (
+            self.options.username
+            and self.options.password
+            and isinstance(self._rpc, WsRPC)
+        ):
+            self._rpc.set_auth_data(
                 self.shelly.get("auth_domain") or self.shelly["id"],
                 self.options.username,
                 self.options.password,
@@ -670,13 +739,23 @@ class RpcDevice:
     ) -> list[dict[str, Any]]:
         """Call RPC method."""
         try:
-            return await self._wsrpc.calls(calls, timeout)
+            # BleRPC only supports single calls, WsRPC supports batching
+            if isinstance(self._rpc, WsRPC):
+                return await self._rpc.calls(calls, timeout)
+
+            # BLE: execute calls sequentially
+            results: list[dict[str, Any]] = []
+            for method, params in calls:
+                result = await self._rpc.call(method, params or {}, timeout)
+                results.append(result)
         except (InvalidAuthError, RpcCallError) as err:
             self._last_error = err
             raise
         except CONNECT_ERRORS as err:
             self._last_error = DeviceConnectionError(err)
-            raise DeviceConnectionError from err
+            raise self._last_error from err
+        else:
+            return results
 
     @property
     def status(self) -> dict[str, Any]:
@@ -751,7 +830,7 @@ class RpcDevice:
     @property
     def connected(self) -> bool:
         """Return true if device is connected."""
-        return self._wsrpc.connected
+        return self._rpc.connected
 
     @property
     def last_error(self) -> ShellyError | None:
